'use strict';

exports.__esModule = true;
exports.getMatchMarker = getMatchMarker;
exports.getInverseMarker = getInverseMarker;

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) newObj[key] = obj[key]; } } newObj['default'] = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

var _vendorTwitterText = require('./vendor/twitter-text');

var _vendorTwitterText2 = _interopRequireDefault(_vendorTwitterText);

var _strings = require('./strings');

var _regex = require('./regex');

var regex = _interopRequireWildcard(_regex);

var warnFn = (console.error || console.warn || console.log || function () {}).bind(console),
    CLASS_NAME_WARNING = _strings.line('\n        Configured to mark text ranges, but a CSS class name to mark\n        them with is not found -- skipping'),
    CLASS_NAME_ERROR_MSG = _strings.line('\n        Argument error: configuration for a className is not provided\n        -- use either a className as the second argument or provide an\n        options object: {classNameFromProps, classNameFromClassNames}');

function getRegExp(value, options, defaultFlags) {
    var flags;
    if (value instanceof RegExp) {
        return value;
    } else {
        // options.flags can be used to set flags on the RegExp
        flags = options && options.flags;
        return new RegExp('' + value, flags || defaultFlags);
    }
}

function getClassNameFromOptions(options) {
    var fromProps, fromClassNames, fallback;
    if (typeof options === 'string') {
        return {
            className: options
        };
    }
    fromProps = options.classNameFromProps;
    fromClassNames = options.classNameFromClassNames;
    fallback = options.fallbackClassName;
    if (!fromProps && !fromClassNames && !fallback) {
        return;
    }
    return {
        getClassName: function getClassName(component, classNames) {
            return fromProps && component.props[fromProps] || classNames[fromClassNames] || fallback;
        }
    };
}

function getMatchMarker(value, options) {
    var rx, processOptsRv, classNameAlways, getClassName;
    if (!value) {
        return function () {};
    }
    // always use a RegExp
    rx = getRegExp(value, options);
    if (!rx.global) {
        warnFn('If the global flag is not set, only the first match will be found');
    }
    if (!options) {
        throw new Error(CLASS_NAME_ERROR_MSG);
    }
    processOptsRv = getClassNameFromOptions(options);
    if (processOptsRv.className) {
        classNameAlways = processOptsRv.className;
    } else if (processOptsRv.getClassName) {
        getClassName = processOptsRv.getClassName;
    } else {
        throw new Error(CLASS_NAME_ERROR_MSG);
    }
    return function markMatches(text, markRange, component, classNames) {
        var className = classNameAlways || getClassName(component, classNames);
        if (!className) {
            warnFn(CLASS_NAME_WARNING);
            return;
        }
        var m = rx.exec(text);
        if (!m) {
            return;
        }
        do {
            markRange(m.index, rx.lastIndex, className);
        } while (rx.global && (m = rx.exec(text)));
    };
}

function getInverseMarker(value, options) {
    var rx, processOptsRv, classNameAlways, getClassName;
    if (!value) {
        return function () {};
    }
    // always use a RegExp
    rx = getRegExp(value, options);
    if (!options) {
        throw new Error(CLASS_NAME_ERROR_MSG);
    }
    processOptsRv = getClassNameFromOptions(options);
    if (processOptsRv.className) {
        classNameAlways = processOptsRv.className;
    } else if (processOptsRv.getClassName) {
        getClassName = processOptsRv.getClassName;
    } else {
        throw new Error(CLASS_NAME_ERROR_MSG);
    }
    return function markInverseMatches(text, markRange, component, classNames) {
        var className = classNameAlways || getClassName(component, classNames);
        if (!className) {
            warnFn(CLASS_NAME_WARNING);
            return;
        }
        var ci = 0,
            m = rx.exec(text);
        if (!m) {
            markRange(0, text.length, className);
            return;
        }
        do {
            if (m.index !== ci) {
                markRange(ci, m.index, className);
            }
            ci = m.index + m[0].length;
        } while (rx.global && (m = rx.exec(text)));
        if (ci < text.length) {
            markRange(ci, text.length, className);
        }
    };
}

var markEmail = getMatchMarker(regex.EMAIL_GLOBAL, {
    classNameFromProps: 'classEmail',
    classNameFromClassNames: 'email'
});

exports.markEmail = markEmail;
var markNonDigits = getMatchMarker(/\D+/g, {
    classNameFromProps: 'classNonDigits',
    classNameFromClassNames: 'nonDigits'
});

exports.markNonDigits = markNonDigits;
var markNonEmail = getInverseMarker(regex.EMAIL, {
    classNameFromProps: 'classNonEmail',
    classNameFromClassNames: 'nonEmail'
});

exports.markNonEmail = markNonEmail;
var markNonInt = getInverseMarker(regex.INT, {
    classNameFromProps: 'classNonInt',
    classNameFromClassNames: 'nonInt'
});

exports.markNonInt = markNonInt;
var markNonEnNumeric = getInverseMarker(regex.NUMERIC_EN, {
    classNameFromProps: 'classNonNumeric',
    classNameFromClassNames: 'nonNumeric'
});

exports.markNonEnNumeric = markNonEnNumeric;
var markNonNumeric = markNonEnNumeric;

exports.markNonNumeric = markNonNumeric;
var markNonEuNumeric = getInverseMarker(regex.NUMERIC_EU, {
    classNameFromProps: 'classNonNumeric',
    classNameFromClassNames: 'nonNumeric'
});

exports.markNonEuNumeric = markNonEuNumeric;
var markNonUint = getInverseMarker(regex.UINT, {
    classNameFromProps: 'classNonUint',
    classNameFromClassNames: 'nonUint'
});

exports.markNonUint = markNonUint;
var markNonUrl = getInverseMarker(_vendorTwitterText2['default'].regexen.extractUrl, {
    classNameFromProps: 'classNonUrl',
    classNameFromClassNames: 'nonUrl'
});

exports.markNonUrl = markNonUrl;
var markUrls = getMatchMarker(_vendorTwitterText2['default'].regexen.extractUrl, {
    classNameFromProps: 'classUrl',
    classNameFromClassNames: 'url'
});
exports.markUrls = markUrls;