'use strict';

exports.__esModule = true;
exports.makeSelectionRange = makeSelectionRange;
exports.filteredMap = filteredMap;
exports.getIsRequiredChecker = getIsRequiredChecker;
exports.numericPropCheck = numericPropCheck;
exports.positiveNumericPropCheck = positiveNumericPropCheck;

function makeSelectionRange(_x, _x2) {
    var _again = true;

    _function: while (_again) {
        var node = _x,
            textOffset = _x2;
        _again = false;

        var range, child, len, i;

        if (textOffset > node.textContent.length) {
            return;
        }
        if (node.nodeType === Node.TEXT_NODE) {
            range = document.createRange();
            range.setStart(node, textOffset);
            return range;
        }
        if (node.nodeType === Node.ELEMENT_NODE) {
            len = node.childNodes.length;
            i = 0;
            for (; i < len; i++) {
                child = node.childNodes[i];
                if (textOffset > child.textContent.length) {
                    textOffset -= child.textContent.length;
                } else {
                    _x = child;
                    _x2 = textOffset;
                    _again = true;
                    range = child = len = i = undefined;
                    continue _function;
                }
            }
        }
    }
}

function filteredMap(arr, fn) {
    var rv = [],
        max = arr.length;
    var i = 0,
        v = undefined;
    for (; i < max; i++) {
        v = fn(arr[i]);
        if (v != null) {
            rv.push(v);
        }
    }
    return rv;
}

function getIsRequiredChecker(checker) {
    return function requiredChecker(props, propName) {
        if (props[propName] == null) {
            return new Error('Invalid prop: ' + propName + ' is required.');
        }
        return checker(props, propName);
    };
}

function numericPropCheck(props, propName) {
    var value = props[propName];
    if (value == null) {
        return;
    }
    if (isNaN(+value)) {
        return new Error('Invalid: Number or numeric String required');
    }
}

numericPropCheck.isRequired = getIsRequiredChecker(numericPropCheck);

function positiveNumericPropCheck(props, propName) {
    var value = props[propName];
    if (value == null) {
        return;
    }
    if (isNaN(+value)) {
        return new Error('Invalid: ' + propName + ' must be a Number or numeric String');
    } else if (+value < 1) {
        return new Error('Invalid: ' + propName + ' must be greater than 1');
    }
}

positiveNumericPropCheck.isRequired = getIsRequiredChecker(positiveNumericPropCheck);